@@ -209,16 +209,46 @@ void UkwsIndicator::rmWinbox(UkwsWindowBox *winbox)
 
 void UkwsIndicator::cleanAllWinbox()
 {
-    // 等待处理完成，并在等待时处理其他事件
+    QTime curTime;
     UkwsWorker *worker;
+
+    // 通知worker，终止处理后续事宜
     foreach(worker, workerList) {
         worker->stopWork();
+    }
 
-        while (!worker->doingThread->isFinished()) {
-            QCoreApplication::processEvents();
+    // 等待处理完成，并在等待时处理其他事件
+    // 最大事件处理时间1000ms，防止不断上报其他事件，从而影响后续逻辑的执行
+    curTime = QTime::currentTime();
+    curTime.start();
+    foreach(worker, workerList) {
+        while (!worker->isStopped() && (curTime.elapsed() < 1000)) {
+            // 最大事件处理时间50ms，防止不断上报其他事件，从而影响后续逻辑的执行
+            QCoreApplication::processEvents(QEventLoop::AllEvents, 50);
         }
-        // 停止所有更新缩略图的线程
-        worker->doingThread->quit();
+
+        // 由于未知问题，存在worker已停止，线程未完成的情况，此时直接终止线程即可
+        if (worker->isStopped() && !worker->doingThread->isFinished()) {
+            // 强行停止线程
+            worker->doingThread->terminate();
+        }
+    }
+
+    curTime = QTime::currentTime();
+    curTime.start();
+    foreach(worker, workerList) {
+        // 等待线程终止
+        while (!worker->doingThread->wait(10) && (curTime.elapsed() < 100)) {
+            // 最大事件处理时间50ms，防止不断上报其他事件，从而影响后续逻辑的执行
+            QCoreApplication::processEvents(QEventLoop::AllEvents, 50);
+        }
+    }
+
+    foreach(worker, workerList) {
+        // 上述等待后线程还未结束，告警
+        if (!worker->doingThread->isFinished())
+            qWarning() << "UkwsIndicator terminate thread"
+                       << workerList.indexOf(worker) << "timeout";
 
         // doingThread只是保存索引，无父子关系，故需要手动释放
         worker->doingThread->deleteLater();
@@ -245,7 +275,7 @@ UkwsWindowBox *UkwsIndicator::getWinbox(int winboxIndex)
 
 void UkwsIndicator::reloadWindowList(int boxMinHeight)
 {
-    if (winboxList.size() != 0)
+    if (winboxList.size() != 0 || workerList.size() != 0)
         cleanAllWinbox();
 
     wmOperator->updateWindowList();
@@ -282,8 +312,10 @@ void UkwsIndicator::reloadWindowList(int boxMinHeight)
         wb->setIconByWnck();
         wb->setTitle(wnck_window_get_name(win));
 
-        if (showMode == UkwsIndicatorShowMode::ShowModeTiling)
+        if (showMode == UkwsIndicatorShowMode::ShowModeTiling) {
             wb->dragable = true;
+            wb->setTitleAutoHide(true);
+        }
 
         addWinbox(wb);
     }
@@ -356,7 +388,6 @@ void UkwsIndicator::reShow(UkwsIndicatorShowMode mode, int minScale)
 //    QDesktopWidget *desktop = QApplication::desktop();
 
     // 自当前屏幕上显示indicator
-
     QRect screenRect;
     int screenCount = QGuiApplication::screens().count();
     int screenIndex = -1;
@@ -388,7 +419,8 @@ void UkwsIndicator::reShow(UkwsIndicatorShowMode mode, int minScale)
         maxWidth = maxWidth * config->workspacePrimaryAreaUnits / config->workspaceAllUnits;
         maxHeight = maxHeight;
     }
-    winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / scale) - 0 - 32 - 5 - 5;
+    winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / scale)
+            - 0 - UKWS_ICON_DEFAULT_SIZE - 5 - 5;
 
     // 设置外边距
     mainLayout->setMargin(20);
@@ -409,13 +441,14 @@ void UkwsIndicator::reShow(UkwsIndicatorShowMode mode, int minScale)
     if (winboxList.size() <= 0) {
         showStatus = UkwsWidgetShowStatus::Shown;
         // 工作线程、CPU数量，线程的CPU亲和力等都需要设置
-        this->reSetWindowThumbnailByWnck();
+//        this->reSetWindowThumbnailByWnck();
         return;
     }
 
     for (int i = (minScale * 2 - 1); i > 4; i--) {
         scale = i / 2.0;
-        winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / scale) - 0 - 32 - 5 - 5;
+        winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / scale)
+                - 0 - UKWS_ICON_DEFAULT_SIZE - 5 - 5;
 
         foreach (UkwsWindowBox *wb, winboxList) {
             wb->setWinboxSizeByHeight(winBoxHeight);
@@ -437,7 +470,8 @@ void UkwsIndicator::reShow(UkwsIndicatorShowMode mode, int minScale)
     if (showMode == UkwsIndicatorShowMode::ShowModeTiling)
         actualScale = 2.5;
 
-    winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / actualScale) - 0 - 32 - 5 - 5;
+    winBoxHeight = ((maxHeight - 5 - 5 - 5 - 5) / actualScale)
+            - 0 - UKWS_ICON_DEFAULT_SIZE - 5 - 5;
     foreach (UkwsWindowBox *wb, winboxList) {
         wb->setWinboxSizeByHeight(winBoxHeight);
     }
@@ -554,10 +588,11 @@ bool UkwsIndicator::updateWindowViewPixmap(bool newRequest)
     if (updateDesktopViewHandledId == updateDesktopViewRequestId)
         return false;
 
-    for (i = 0; i < cpus; i++) {
-        worker = workerList.at(i);
-        if (!worker->isStopped())
-            allWorkDone = false;
+    if (workerList.size() > 0) {
+        foreach (worker, workerList) {
+            if (!worker->isStopped())
+                allWorkDone = false;
+        }
     }
 
     if (!allWorkDone)
