@@ -31,7 +31,7 @@ extern "C" {
 }
 
 //#define NOT_REG_WINDOW_SWITCH_HOTKEY
-#define NOT_REG_WORKSPACE_VIEW_HOTKEY
+//#define NOT_REG_WORKSPACE_VIEW_HOTKEY
 
 UkwsManager::UkwsManager(QWidget *parent) : QWidget(parent)
 {
@@ -46,9 +46,13 @@ UkwsManager::UkwsManager(QWidget *parent) : QWidget(parent)
 #endif
 
 #ifndef NOT_REG_WORKSPACE_VIEW_HOTKEY
-    workspaceShortcut = new QHotkey(QKeySequence(Qt::MetaModifier |
-                                                 Qt::Key_Tab),
-                                    true, this);
+    workspaceShortcut1 = new QHotkey(QKeySequence(Qt::ControlModifier |
+                                                  Qt::AltModifier |
+                                                  Qt::Key_W),
+                                     true, this);
+    workspaceShortcut2 = new QHotkey(QKeySequence(Qt::MetaModifier |
+                                                  Qt::Key_Tab),
+                                     true, this);
 #endif
 
 #ifndef NOT_REG_WINDOW_SWITCH_HOTKEY
@@ -57,7 +61,8 @@ UkwsManager::UkwsManager(QWidget *parent) : QWidget(parent)
 #endif
 
 #ifndef NOT_REG_WORKSPACE_VIEW_HOTKEY
-    connect(workspaceShortcut, &QHotkey::activated, this, &UkwsManager::handleWorkspace);
+    connect(workspaceShortcut1, &QHotkey::activated, this, &UkwsManager::handleWorkspace);
+    connect(workspaceShortcut2, &QHotkey::activated, this, &UkwsManager::handleWorkspace);
 #endif
 
     // 每10s检测一次热键注册情况
@@ -80,8 +85,10 @@ UkwsManager::UkwsManager(QWidget *parent) : QWidget(parent)
     // 窗口指示器显示所有工作区中的窗口，但是不显示非当前屏幕的窗口
     ind->wmOperator->needCheckWorkspace = false;
     ind->wmOperator->needCheckScreen = true;
-    ind->setWindowFlags(Qt::FramelessWindowHint | Qt::Tool | Qt::WindowStaysOnTopHint);
-    ws->setWindowFlags(Qt::FramelessWindowHint | Qt::Tool | Qt::WindowStaysOnTopHint);
+    ind->setWindowFlags(Qt::FramelessWindowHint | Qt::Tool |
+                        Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
+    ws->setWindowFlags(Qt::FramelessWindowHint | Qt::Tool |
+                       Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);
 
     connect(ind, &UkwsIndicator::isSelected, this, &UkwsManager::hideIndicatorAndActivate);
     connect(ws, &UkwsWorkspaceManager::isHidden, this, &UkwsManager::hideWorkspace);
@@ -182,17 +189,19 @@ void UkwsManager::hideIndicator()
 
 void UkwsManager::hideIndicatorAndActivate(bool needActivate)
 {
+    // 无论何种状态，隐藏indicator的时候都释放键盘
+    setGrabKeyboard(false);
+
     if (ind->showStatus == UkwsWidgetShowStatus::Constructing)
         ind->stopConstructing(100000);
 
-    if (ind->showStatus == UkwsWidgetShowStatus::Destructing)
-        return;
+//    if (ind->showStatus == UkwsWidgetShowStatus::Destructing)
+//        return;
 
     if ((ind->showStatus == UkwsWidgetShowStatus::Shown) ||
             (ind->showStatus == UkwsWidgetShowStatus::Interrupted)) {
         altCheckTimer.stop();
         ind->reHide(needActivate);
-        setGrabKeyboard(false);
     }
 }
 
@@ -209,8 +218,11 @@ void UkwsManager::checkShortcutStatus()
 #endif
 
 #ifndef NOT_REG_WORKSPACE_VIEW_HOTKEY
-    if (!workspaceShortcut->isRegistered()) {
-        workspaceShortcut->setRegistered(true);
+    if (!workspaceShortcut1->isRegistered()) {
+        workspaceShortcut1->setRegistered(true);
+    }
+    if (!workspaceShortcut2->isRegistered()) {
+        workspaceShortcut2->setRegistered(true);
     }
 #endif
 }
@@ -287,14 +299,6 @@ bool UkwsManager::showWorkspace()
     // 处理所有show事件，完成初始布局
     QCoreApplication::processEvents();
 
-    // 显示当前的工作区
-    QDesktopWidget *desktop = QApplication::desktop();
-    int screenNum = desktop->screenNumber(this);
-    WnckScreen *screen = wnck_screen_get(screenNum);
-    WnckWorkspace *workspace = wnck_screen_get_active_workspace(screen);
-    int workspaceNum = wnck_workspace_get_number(workspace);
-    ws->setShowingIndicator(workspaceNum);
-
     return true;
 }
 
