@@ -22,12 +22,14 @@
 #include <QString>
 #include <QDate>
 #include <QSize>
+#include <QSizePolicy>
 #include <QEvent>
 #include <QResizeEvent>
 
 #include <QDebug>
 #include <QStyleOption>
 #include <QPainter>
+#include <QPainterPath>
 
 #include "ukws_common.h"
 #include "ukws_helper.h"
@@ -53,6 +55,8 @@ UkwsWindowBox::UkwsWindowBox(QWidget *parent) : QWidget(parent)
     frameXid = 0;
     hasFrame = false;
     drag = nullptr;
+    isSelected = false;
+    titleAutoHide = false;
 
     titleLabel = new UkwsWindowExtraLabel();
     iconLabel = new UkwsWindowExtraLabel();
@@ -84,22 +88,19 @@ UkwsWindowBox::UkwsWindowBox(QWidget *parent) : QWidget(parent)
 
     // 设置控件缩放方式
     QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-//    sizePolicy.setHorizontalStretch(0);
-//    sizePolicy.setVerticalStretch(0);
+    sizePolicy.setRetainSizeWhenHidden(true);
     iconLabel->setSizePolicy(sizePolicy);
     sizePolicy.setHorizontalPolicy(QSizePolicy::Expanding);
     titleLabel->setSizePolicy(sizePolicy);
     sizePolicy.setVerticalPolicy(QSizePolicy::Expanding);
 
     // 设置控件最大尺寸
-    iconLabel->resize(QSize(32, 32));
-    titleLabel->setFixedHeight(32);
+    iconLabel->resize(QSize(UKWS_ICON_DEFAULT_SIZE, UKWS_ICON_DEFAULT_SIZE));
+    titleLabel->setFixedHeight(UKWS_TITLE_DEFAULT_HEIGHT);
     titleLabel->setMinimumWidth(1);
     thumbnailLabel->setMinimumSize(QSize(1, 1));
 
-//    iconLabel->setContentsMargins(5, 0, 0, 0);
-    titleLabel->setContentsMargins(0, 0, 5, 0);
-//    thumbnailLabel->setContentsMargins(3, 3, 3, 3);
+    titleLabel->setContentsMargins(0, 0, UKWS_WINDOWBOX_PADDING, 0);
 
     /*
      * 设置控件布局（简单布局，直接手写）
@@ -163,6 +164,27 @@ void UkwsWindowBox::paintEvent(QPaintEvent *event)
     QPainter painter(this);
     style()->drawPrimitive(QStyle::PE_Widget, &styleOpt, &painter, this);
 
+    if (isSelected) {
+        QSize size = this->size();
+
+        // 获取圆角边框区域
+        QRectF rect;
+        QPainterPath path;
+
+        rect = QRectF(UKWS_WINDOWBOX_BORDER, UKWS_WINDOWBOX_BORDER,
+                      size.width() - UKWS_WINDOWBOX_BORDER * 2,
+                      size.height() - UKWS_WINDOWBOX_BORDER * 2);
+        path.addRoundedRect(rect, UKWS_THUMBNAIL_RADIUS, UKWS_THUMBNAIL_RADIUS);
+        rect = QRectF(0, 0, size.width(), size.height());
+        path.addRoundedRect(rect, UKWS_THUMBNAIL_RADIUS + UKWS_WINDOWBOX_BORDER,
+                            UKWS_THUMBNAIL_RADIUS + UKWS_WINDOWBOX_BORDER);
+
+        painter.setRenderHint(QPainter::Antialiasing, false);
+        painter.setBrush(QBrush(QColor(255, 255, 255, 128)));
+        painter.setPen(QPen(QColor(255, 255, 255, 0)));
+        painter.drawPath(path);
+    }
+
     QWidget::paintEvent(event);
 }
 
@@ -173,11 +195,15 @@ void UkwsWindowBox::setSubWidgetSizeByThnSize(int w, int h)
     // 高度调整值：8 + 32 + 16 = 56；
     // 宽度调整值：32 + 5 = 37
     // 标题宽度调整值：
-    titleLabel->setFixedSize(w - 37, 32);
+    int fixW, fixH;
+    fixW = (UKWS_ICON_DEFAULT_WIDTH + UKWS_WINDOWBOX_PADDING);
+    titleLabel->setFixedSize(w - fixW, UKWS_ICON_DEFAULT_HEIGHT);
     this->updateTitleBySize();
 
     // 缩略图控件，外边框4，边框紧贴图片，宽、高占用：4 * 2 = 8
-    thumbnailLabel->setFixedSize(w + 8, h + 8);
+    fixW = UKWS_WINDOWBOX_BORDER * 2;
+    fixH = UKWS_WINDOWBOX_BORDER * 2;
+    thumbnailLabel->setFixedSize(w + fixW, h + fixH);
 }
 
 void UkwsWindowBox::setWinboxSizeByHeight(int height)
@@ -187,7 +213,12 @@ void UkwsWindowBox::setWinboxSizeByHeight(int height)
     // 缩略图控件，外边距8，外边框4，边框紧贴图片，宽占用：(8 + 4) * 2 = 24，高占用：8 + 4 = 12；
     // 高度调整值：16 + 32 + 12 = 60；
     // 宽度调整值：24
-    int thnHeight = height - 60;
+    int fixW, fixH, thnHeight;
+    fixW = (UKWS_THUMBNAIL_MARGIN + UKWS_WINDOWBOX_BORDER) * 2;
+    fixH = (UKWS_WINDOWBOX_BORDER + UKWS_WINDOWBOX_PADDING) * 2
+            + UKWS_ICON_DEFAULT_HEIGHT
+            + (UKWS_THUMBNAIL_MARGIN + UKWS_WINDOWBOX_BORDER);
+    thnHeight = height - fixH;
 
     int w, h;
     float scale;
@@ -211,7 +242,7 @@ void UkwsWindowBox::setWinboxSizeByHeight(int height)
     h = int(h * scale);
 
     this->setSubWidgetSizeByThnSize(w, h);
-    this->setFixedSize(w + 24, height);
+    this->setFixedSize(w + fixW, height);
 }
 
 WnckWindow *UkwsWindowBox::getWnckWindow()
@@ -347,22 +378,56 @@ void UkwsWindowBox::setOrigThumbnailByWnck()
                                                                     winBottomOffset);
 }
 
-void UkwsWindowBox::setThumbnail(QPixmap origPixmap)
+void UkwsWindowBox::updateThumbnail()
 {
     QSize labelSize = thumbnailLabel->size();
+
+    thnUnselectedPixmap = QPixmap(labelSize.width(), labelSize.height());
+    thnUnselectedPixmap.fill(Qt::transparent);
+//    thnSelectedPixmap = QPixmap(labelSize.width(), labelSize.height());
+//    thnSelectedPixmap.fill(Qt::transparent);
+
+    // 自绘边框宽度为4px，纯缩略图大小为长宽需要减8
+    QPixmap origThn, radiusThn;
+    origThn = thumbnailLabel->originalQPixmap.scaled(labelSize.width() - UKWS_WINDOWBOX_BORDER * 2,
+                                                     labelSize.height() - UKWS_WINDOWBOX_BORDER * 2,
+                                                     Qt::KeepAspectRatio,
+                                                     Qt::SmoothTransformation);
+
+    QPainter painter;
+    radiusThn = makeRadiusPixmap(origThn, UKWS_THUMBNAIL_RADIUS);
+    painter.begin(&thnUnselectedPixmap);
+    painter.drawPixmap(UKWS_WINDOWBOX_BORDER, UKWS_WINDOWBOX_BORDER,
+                       radiusThn.width(), radiusThn.height(), radiusThn);
+    painter.end();
+    thnSelectedPixmap = thnUnselectedPixmap.copy();
+
+    // 获取圆角边框区域
+    QRectF rect;
+    QPainterPath path;
+
+    rect = QRectF(UKWS_WINDOWBOX_BORDER, UKWS_WINDOWBOX_BORDER,
+                  labelSize.width() - UKWS_WINDOWBOX_BORDER * 2,
+                  labelSize.height() - UKWS_WINDOWBOX_BORDER * 2);
+    path.addRoundedRect(rect, UKWS_THUMBNAIL_RADIUS, UKWS_THUMBNAIL_RADIUS);
+    rect = QRectF(0, 0, labelSize.width(), labelSize.height());
+    path.addRoundedRect(rect, UKWS_THUMBNAIL_RADIUS + UKWS_WINDOWBOX_BORDER,
+                        UKWS_THUMBNAIL_RADIUS + UKWS_WINDOWBOX_BORDER);
+
+    painter.begin(&thnSelectedPixmap);
+    painter.setRenderHint(QPainter::Antialiasing, false);
+    painter.setBrush(QBrush(QColor(255, 255, 255, 128)));
+    painter.setPen(QPen(QColor(255, 255, 255, 0)));
+    painter.drawPath(path);
+    painter.end();
+}
+
+void UkwsWindowBox::setThumbnail(QPixmap origPixmap)
+{
+
     thumbnailLabel->originalQPixmap = origPixmap;
-
-    // 缩略图控件包含4px的外边框，需要减去外边框的大小
-    scaledThumbnail = origPixmap.scaled(labelSize.width() - 8,
-                                        labelSize.height() - 8,
-                                        Qt::KeepAspectRatio,
-                                        Qt::SmoothTransformation);
-
-    QSize thumbnailSize = scaledThumbnail.size();
-    QSize size = (thumbnailLabel->contentsRect().size() - thumbnailSize) / 2;
-    thumbnailOffset = QPoint(size.width() + 4, size.height() + 4);
-    scaledThumbnail = makeRadiusPixmap(scaledThumbnail, 6);
-    thumbnailLabel->setPixmap(scaledThumbnail);
+    updateThumbnail();
+    thumbnailLabel->setPixmap(thnUnselectedPixmap);
 }
 
 void UkwsWindowBox::setThumbnailByWnck()
@@ -375,18 +440,8 @@ void UkwsWindowBox::setThumbnailByWnck()
                                                                         winRightOffset,
                                                                         winTopOffset,
                                                                         winBottomOffset);
-
-    // 缩略图控件包含4px的外边框，需要减去外边框的大小
-    scaledThumbnail = thumbnailLabel->originalQPixmap.scaled(labelSize.width() - 8,
-                                                             labelSize.height() - 8,
-                                                             Qt::KeepAspectRatio,
-                                                             Qt::SmoothTransformation);
-
-    QSize thumbnailSize = scaledThumbnail.size();
-    QSize size = (thumbnailLabel->contentsRect().size() - thumbnailSize) / 2;
-    thumbnailOffset = QPoint(size.width() + 4, size.height() + 4);
-    scaledThumbnail = makeRadiusPixmap(scaledThumbnail, 6);
-    thumbnailLabel->setPixmap(scaledThumbnail);
+    updateThumbnail();
+    thumbnailLabel->setPixmap(thnUnselectedPixmap);
 }
 
 void UkwsWindowBox::setDragIconSize(QSize size)
@@ -406,26 +461,43 @@ QString UkwsWindowBox::getTitle()
 
 void UkwsWindowBox::setThumbnailHover()
 {
-
+    if (titleAutoHide) {
+        iconLabel->show();
+        titleLabel->show();
+    }
+    thumbnailLabel->setPixmap(thnSelectedPixmap);
 }
 
 void UkwsWindowBox::setThumbnailNormal()
 {
-
+    if (titleAutoHide) {
+        iconLabel->hide();
+        titleLabel->hide();
+    }
+    thumbnailLabel->setPixmap(thnUnselectedPixmap);
 }
 
 void UkwsWindowBox::setWindowBoxSelected()
 {
-    this->setStyleSheet("QWidget#winbox{padding:0px;"
-                        "border:4px solid rgb(255, 255, 255, 127);"
-                        "border-radius: 6px;}");
+    isSelected = true;
+    update();
 }
 
 void UkwsWindowBox::setWindowBoxUnselected()
 {
-    this->setStyleSheet("QWidget#winbox{padding:0px;"
-                        "border:4px solid rgb(255, 255, 255, 0);"
-                        "border-radius: 6px;}");
+    isSelected = false;
+    update();
+}
+
+void UkwsWindowBox::setTitleAutoHide(bool autoHide)
+{
+    titleAutoHide = autoHide;
+
+    // 设置了自动隐藏则即刻隐藏标题栏
+    if (titleAutoHide) {
+        iconLabel->hide();
+        titleLabel->hide();
+    }
 }
 
 void UkwsWindowBox::moveToWorkspace(int wsIndex)
@@ -473,8 +545,8 @@ void UkwsWindowBox::scaleDragPixmap()
     scaleTimer.start();
 
     // 设置缩放大小
-    QSize size = scaledThumbnail.size() - scaleUnitSize * (UKWS_DRAG_SCALE_TIMES - scaleTimes);
-    QPixmap pixmap = scaledThumbnail.scaled(size, Qt::KeepAspectRatio,
+    QSize size = thnUnselectedPixmap.size() - scaleUnitSize * (UKWS_DRAG_SCALE_TIMES - scaleTimes);
+    QPixmap pixmap = thnUnselectedPixmap.scaled(size, Qt::KeepAspectRatio,
                                             Qt::FastTransformation);
     drag->setPixmap(pixmap);
     update();
@@ -533,10 +605,10 @@ bool UkwsWindowBox::eventFilter(QObject *watched, QEvent *event)
                 return true;
 
             // 缩略图置灰
-            QPixmap tempPixmap = scaledThumbnail;
+            QPixmap tempPixmap = thnUnselectedPixmap;
             QPainter painter;
             painter.begin(&tempPixmap);
-            painter.fillRect(scaledThumbnail.rect(), QColor(0, 0, 0, 159));
+            painter.fillRect(thnUnselectedPixmap.rect(), QColor(0, 0, 0, 159));
             painter.end();
             thumbnailLabel->setPixmap(tempPixmap);
 
@@ -549,26 +621,26 @@ bool UkwsWindowBox::eventFilter(QObject *watched, QEvent *event)
             dataStream << parentIndex << index << title;
             mimeData->setData("application/x-dnditemdata", byteData);
             drag->setMimeData(mimeData);
-//            drag->setPixmap(scaledThumbnail);
-            drag->setPixmap(scaledThumbnail.scaled(dragIconSize, Qt::KeepAspectRatio,
+//            drag->setPixmap(thnUnselectedPixmap);
+            drag->setPixmap(thnUnselectedPixmap.scaled(dragIconSize, Qt::KeepAspectRatio,
                                                           Qt::FastTransformation));
 
             // 事件发生时的坐标，减去thn边框的宽度，获得实际图片上的坐标
             QPoint hotSpot = (mouseEvent->pos() - thumbnailOffset) *
-                    (float)drag->pixmap().size().width() / (float)scaledThumbnail.width();
+                    (float)drag->pixmap().size().width() / (float)thnUnselectedPixmap.width();
             drag->setHotSpot(hotSpot);
 
             // 设置缩放大小
-            scaleUnitSize = (scaledThumbnail.size() - drag->pixmap().size()) / UKWS_DRAG_SCALE_TIMES;
+            scaleUnitSize = (thnUnselectedPixmap.size() - drag->pixmap().size()) / UKWS_DRAG_SCALE_TIMES;
 
             // 设置拖拽图片缩放动画的定时器
             scaleTimer.start();
             scaleTimes = UKWS_DRAG_SCALE_TIMES;
 
             if (drag->exec()) {
-                thumbnailLabel->setPixmap(scaledThumbnail);
+                thumbnailLabel->setPixmap(thnUnselectedPixmap);
             } else {
-                thumbnailLabel->setPixmap(scaledThumbnail);
+                thumbnailLabel->setPixmap(thnUnselectedPixmap);
             }
 
             drag->deleteLater();
