@@ -85,11 +85,15 @@ void UkwsWorker::doWork()
     // 设置状态
     status = UkwsWorker::Stopped;
     emit workDone();
+
+    // 显示调用quit()来退出事件循环，结束线程
+    this->doingThread->quit();
 }
 
 void UkwsWorker::stopWork()
 {
-    status = UkwsWorker::Stopping;
+    if (status != UkwsWorker::Stopped)
+        status = UkwsWorker::Stopping;
 }
 
 bool UkwsWorker::isStopped()
