@@ -40,9 +40,12 @@ UkwsWorkspaceManager::UkwsWorkspaceManager(QWidget *parent) : QWidget(parent)
 {
     wmOperator = new UkwsWnckOperator;
     indStack = new QStackedWidget;
+    newWorkspaceBtn = new UkwsNewWorkspaceButton;
+
     mainLayout = new QHBoxLayout;
     wsboxLayout = new QVBoxLayout;
     topSpacer = new QSpacerItem(0, 0, QSizePolicy::Fixed);
+
     showStatus = UkwsWidgetShowStatus::Hidden;
     config = nullptr;
 
@@ -83,6 +86,7 @@ void UkwsWorkspaceManager::reloadWorkspace(int minScale)
     QRect screenRect = primaryScreen->geometry();
     int screenNum = screenList.indexOf(primaryScreen);
     WnckScreen *screen = wnck_screen_get(screenNum);
+
     float scale = (float)config->workspaceItemUnits / config->workspaceAllUnits;
 
     int w = screenRect.width() * scale;
@@ -148,6 +152,19 @@ void UkwsWorkspaceManager::reloadWorkspace(int minScale)
 
     for (int i = 0; i < size; i++)
         indList.at(i)->reShow(UkwsIndicator::ShowModeTiling, minScale);
+
+    // 显示当前的工作区
+    WnckWorkspace *workspace = wnck_screen_get_active_workspace(screen);
+    int workspaceNum = wnck_workspace_get_number(workspace);
+    setShowingIndicator(workspaceNum);
+
+    wsboxLayout->addWidget(newWorkspaceBtn);
+    newWorkspaceBtn->setSizeByButtonSize(w, h);
+//    newWorkspaceBtn->show();
+    newWorkspaceBtn->hide();
+
+    if (size >= UKWS_WORKSPACE_MAX)
+        newWorkspaceBtn->hide();
 }
 
 void UkwsWorkspaceManager::reShow(int minScale)
@@ -195,7 +212,7 @@ void UkwsWorkspaceManager::setShowingIndicator(int index)
     int idx = index;
 
     if (size <= 0) {
-        qCritical("Indicator list is empty...\n", index);
+        qCritical("Indicator list is empty, but get index:%d ...\n", index);
         return;
     }
 
@@ -217,12 +234,10 @@ void UkwsWorkspaceManager::setShowingIndicator(int index)
 
     UkwsWorkspaceBox *wsbox;
     foreach (wsbox, spaceBoxList) {
-        wsbox->setProperty("selected", false);
-        wsbox->setStyle(QApplication::style());
+        wsbox->setSelectStatus(false);
     }
     wsbox = spaceBoxList.at(idx);
-    wsbox->setProperty("selected", true);
-    wsbox->setStyle(QApplication::style());
+    wsbox->setSelectStatus(true);
 }
 
 void UkwsWorkspaceManager::selectWinbox(bool needActivate)
@@ -288,12 +303,16 @@ void UkwsWorkspaceManager::doIndicatorWindowViewChange(int indIndex)
 }
 
 QString UkwsWorkspaceManager::getBackgroundFileByGSettings(QString schemaDir,
-                                                    QString schemaUrl,
-                                                    QString keyName)
+                                                           QString schemaUrl,
+                                                           QString keyName)
 {
     QUrl url;
     QString fileUrl = QString("");
 
+    /*
+     * 不再使用glib的方式获取gsettings，使用QGsettings
+     */
+#if 0
     GSettingsSchemaSource *schema_source = NULL;
     GSettingsSchema *schema = NULL;
     GSettings *settings = NULL;
@@ -349,33 +368,89 @@ GSFREE:
 
     if (schema_source != NULL)
         g_settings_schema_source_unref(schema_source);
+#endif
+
+    Q_UNUSED(schemaDir);
+
+    if (QGSettings::isSchemaInstalled(schemaUrl.toUtf8())) {
+        QGSettings gsettings(schemaUrl.toUtf8());
+
+        const QStringList keyList = gsettings.keys();
+//        qDebug() << schemaUrl << "Key List:" << keyList;
+        if (keyList.contains(keyName)) {
+            QString name = gsettings.get(keyName).toString();
+            url = QUrl::fromLocalFile(name);
+            fileUrl = url.toString().replace(QRegExp("^file:/"), "");
+//            qDebug() << "Get background file:" << fileUrl;
+        } else {
+            qWarning() << QString("Cannot get gsettings key(%1) value").arg(keyName);
+        }
+    }
 
     return fileUrl;
 }
 
+QString UkwsWorkspaceManager::getBackgroundColorGSettings(QString schemaDir,
+                                                          QString schemaUrl,
+                                                          QString keyName)
+{
+    QString colorString = "";
+
+    /*
+     * 不再使用glib的方式获取gsettings，使用QGsettings
+     */
+
+    Q_UNUSED(schemaDir);
+
+    if (QGSettings::isSchemaInstalled(schemaUrl.toUtf8())) {
+        QGSettings gsettings(schemaUrl.toUtf8());
+
+        const QStringList keyList = gsettings.keys();
+        if (keyList.contains(keyName)) {
+            colorString = gsettings.get(keyName).toString();
+//            qDebug() << "Get background color:" << colorString;
+        } else {
+            qWarning() << QString("Cannot get gsettings key(%1) value").arg(keyName);
+        }
+    }
+
+    return colorString;
+}
+
 void UkwsWorkspaceManager::getBackground()
 {
     QString filePath;
 
     filePath = getBackgroundFileByGSettings("/usr/share/glib-2.0/schemas/",
                                             "org.mate.background",
-                                            "picture-filename");
+                                            "pictureFilename");
 
     if (filePath == "") {
+        // 无法从ukui桌面环境获取背景文件，则获取背景颜色
+        QString colorName = getBackgroundColorGSettings("/usr/share/glib-2.0/schemas/",
+                                                        "org.mate.background",
+                                                        "primaryColor");
+        if (colorName != "") {
+            if (background.isNull()) {
+                background = QPixmap(480, 270);
+            }
+            background.fill(QColor(colorName));
+            return;
+        }
+
+        // 无法获取背景色，则继续获取gnome桌面环境的背景图片
         filePath = getBackgroundFileByGSettings("/usr/share/glib-2.0/schemas/",
                                                 "org.gnome.desktop.background",
-                                                "picture-uri");
-    }
-
-    if (filePath == "") {
-        qWarning() << "Cannot get background image, use default:" << UKWS_WORKSPACE_DEFAULT_BACKGROUND;
-        filePath = UKWS_WORKSPACE_DEFAULT_BACKGROUND;
+                                                "pictureUri");
+        if (filePath == "") {
+            qWarning() << "Cannot get background image, use default:" << UKWS_WORKSPACE_DEFAULT_BACKGROUND;
+            filePath = UKWS_WORKSPACE_DEFAULT_BACKGROUND;
+        }
     }
 
     QImage img;
     img.load(filePath);
     background = QPixmap::fromImage(img);
-
 }
 
 void UkwsWorkspaceManager::setBackgroundImage(int width, int height)
@@ -433,6 +508,7 @@ void UkwsWorkspaceManager::cleanAllWorkspace()
         wsbox->deleteLater();
     }
     spaceBoxList.clear();
+    wsboxLayout->removeWidget(newWorkspaceBtn);
 
     // 清理indicator
     foreach(UkwsIndicator *ind, indList) {
@@ -457,6 +533,7 @@ bool UkwsWorkspaceManager::eventFilter(QObject *object, QEvent *event)
         }
 
         if (event->type() == QEvent::MouseButtonRelease) {
+            changeWorkspace(indStack->currentIndex());
             reHide();
             return true;
         }
@@ -477,6 +554,7 @@ bool UkwsWorkspaceManager::eventFilter(QObject *object, QEvent *event)
         if (event->type() == QEvent::WindowDeactivate) {
             if (showStatus == UkwsWidgetShowStatus::Shown ||
                      showStatus == UkwsWidgetShowStatus::Constructing) {
+                changeWorkspace(indStack->currentIndex());
                 reHide();
             }
             return true;
