@@ -24,6 +24,7 @@
 #include "ukws_flowlayout.h"
 #include "ukws_wnck_operator.h"
 #include "ukws_workspace_box.h"
+#include "ukws_new_workspace_button.h"
 #include "ukws_config.h"
 
 #include <QWidget>
@@ -35,9 +36,11 @@
 #include <QString>
 #include <QStackedWidget>
 #include <QPixmap>
+#include <QGSettings>
 
 #define UKWS_WORKSPACE_MAX_SCALE 3
 #define UKWS_WORKSPACE_DEFAULT_BACKGROUND   "/usr/share/ukui-window-switch/data/default-background.png"
+#define UKWS_WORKSPACE_MAX  4
 
 class UkwsWorkspaceManager: public QWidget
 {
@@ -51,6 +54,7 @@ public:
     void reShow(int minScale=UKWS_WORKSPACE_MAX_SCALE);
     void reHide();
     QString getBackgroundFileByGSettings(QString schemaDir, QString schemaUrl, QString keyName);
+    QString getBackgroundColorGSettings(QString schemaDir, QString schemaUrl, QString keyName);
     void getBackground();
     void setBackgroundImage(int width = 0, int height = 0);
     void cleanAllWorkspace();
@@ -77,6 +81,7 @@ private:
     QList<UkwsWorkspaceBox *> spaceBoxList;
 
     QStackedWidget *indStack;
+    UkwsNewWorkspaceButton *newWorkspaceBtn;
 
     QHBoxLayout *mainLayout;
     QVBoxLayout *wsboxLayout;
